@@ -1,20 +1,24 @@
-from __future__ import unicode_literals
 import objc
-from PyObjCTools.TestSupport import *
 from PyObjCTest.initialize import OC_TestInitialize
+from PyObjCTools.TestSupport import TestCase
 
-class OC_TestInitializePython (OC_TestInitialize):
+
+class OC_TestInitializePython(OC_TestInitialize):
     def init(self):
         return objc.super(OC_TestInitializePython, self).init()
 
-OBJECT_LIST=[]
-class OC_TestInitializePython2 (OC_TestInitialize):
+
+OBJECT_LIST = []
+
+
+class OC_TestInitializePython2(OC_TestInitialize):
     def init(self):
         self = objc.super(OC_TestInitializePython2, self).init()
         OBJECT_LIST.append(self)
         return self
 
-class TestInitializing (TestCase):
+
+class TestInitializing(TestCase):
     #
     # These tests make sure that we don't call retain/release on objects
     # that are not yet initialized.
@@ -80,6 +84,3 @@ class TestInitializing (TestCase):
         self.assertEqual(s, "hello")
         v = OC_TestInitialize.numUninitialized()
         self.assertEqual(v, start)
-
-if __name__ == "__main__":
-    main()
