@@ -1,7 +1,6 @@
-from PyObjCTools.TestSupport import *
 import objc
-
 from PyObjCTest.methodlookup import PyObjC_MethodLookup1, PyObjC_MethodLookup2
+from PyObjCTools.TestSupport import TestCase
 
 
 class TestSuperObject(TestCase):
@@ -113,7 +112,9 @@ class TestMethodResolution(TestCase):
         self.assertEqual(o.pyobjc__instanceCount.selector, b"pyobjc__instanceCount")
 
         self.assertEqual(o.pyobjc_setObject_forKey_(1, 2), [1, 2])
-        self.assertEqual(o.pyobjc_setObject_forKey_.selector, b"pyobjc_setObject:forKey:")
+        self.assertEqual(
+            o.pyobjc_setObject_forKey_.selector, b"pyobjc_setObject:forKey:"
+        )
 
     def test_class_specials(self):
         # Harder cases to get right: selectors with an embedded underscore
@@ -128,14 +129,19 @@ class TestMethodResolution(TestCase):
         self.assertEqual(o.pyobjc__classCount.selector, b"pyobjc__classCount")
 
         self.assertEqual(o.pyobjc_setObject_forKey_(1, 2), [2, 1])
-        self.assertEqual(o.pyobjc_setObject_forKey_.selector, b"pyobjc_setObject:forKey:")
+        self.assertEqual(
+            o.pyobjc_setObject_forKey_.selector, b"pyobjc_setObject:forKey:"
+        )
 
     def test_explicit_choice(self):
         s = PyObjC_MethodLookup1.pyobjc_classMethods.both
         self.assertTrue(s.isClassMethod)
 
         self.assertRaises(
-            AttributeError, getattr, PyObjC_MethodLookup1.pyobjc_classMethods, "instance5"
+            AttributeError,
+            getattr,
+            PyObjC_MethodLookup1.pyobjc_classMethods,
+            "instance5",
         )
 
         s = PyObjC_MethodLookup1.pyobjc_instanceMethods.both
@@ -146,7 +152,3 @@ class TestMethodResolution(TestCase):
             PyObjC_MethodLookup1.pyobjc_instanceMethods,
             "clsmeth5",
         )
-
-
-if __name__ == "__main__":
-    main()
